@@ -517,6 +517,9 @@ class FingerprintImageEnhancer(object):
         self._binim = 255 * self._binim.astype('uint8')
         return(self._binim)
 
-def enhance_Fingerprint(img):
-    image_enhancer = FingerprintImageEnhancer()  # Create object called image_enhancer
+def enhance_Fingerprint(img, ridge_segment_blksze=16, ridge_segment_thresh=0.1, gradient_sigma=1, block_sigma=7, orient_smooth_sigma=7,
+                 ridge_freq_blksze=38, ridge_freq_windsze=5, min_wave_length=5, max_wave_length=15, kx=0.65, ky=0.65, angleInc=3.0, ridge_filter_thresh=-3):
+
+    image_enhancer = FingerprintImageEnhancer(ridge_segment_blksze, ridge_segment_thresh, gradient_sigma, block_sigma, orient_smooth_sigma,
+                 ridge_freq_blksze, ridge_freq_windsze, min_wave_length, max_wave_length, kx, ky, angleInc, ridge_filter_thresh)  # Create object called image_enhancer
     return(image_enhancer.enhance(img))
\ No newline at end of file
